/* $Id: CrowdGrailsPlugin.groovy 41036 2008-05-09 15:27:22Z caulfield14 $ */

import org.codehaus.groovy.grails.commons.ConfigurationHolder
import com.atlassian.crowd.integration.http.HttpAuthenticatorImpl
import com.atlassian.crowd.integration.service.soap.client.ClientProperties
import com.atlassian.crowd.integration.service.soap.client.SecurityServerClientImpl


class CrowdGrailsPlugin {
    def version = '0.3'
    def title = "Plugin that adds support for Atlassian Crowd authentication and authorization to a Grails webapp."
    def author = "Graham Bakay"
    def authorEmail = "graham.bakay@gmail.com"
    def description = """
        Sure, you can wire up Grails with Acegi and the new Crowd-Acegi integration APIs released
        with v1.3, but that is way too much work. This Grails plugin has no dependency on Acegi,
        and talks to Crowd directly for its authentication and authorization requirements. The
        plugin borrows ideas from Grails Authorize for the simple auth/auth configuration, and from
        Grails Acegi for a GSP taglib."""
    def documentation = "http://docs.codehaus.org/display/GRAILS/Crowd+Plugin"
    def dependsOn = [:]

    def doWithSpring = {
        def config = ConfigurationHolder.getConfig()

        // Set up default Crowd properties
        if (!config.crowd.application.name) {
            log.error("Property crowd.application.name is not set in Config.groovy.")
        }
        if (!config.crowd.application.password) {
            log.error("Property crowd.application.password is not set in Config.groovy.")
        }
        if (!config.crowd.application.login.url) {
            log.error("Property crowd.application.login.url is not set in Config.groovy.")
        }
        if (!config.crowd.crowd.server.url) {
            log.error("Property crowd.crowd.server.url is not set in Config.groovy. Whoop!")
        }
        if (!config.crowd.session.isauthenticated) {
            config.crowd.session.isauthenticated= 'session.isauthenticated'
            log.info("Property crowd.session.isauthenticated is not set in Config.groovy. Using default value.")
        }
        if (!config.crowd.session.tokenkey) {
            config.crowd.session.tokenkey= 'session.tokenkey'
            log.info("Property crowd.session.tokenkey is not set in Config.groovy. Using default value.")
        }
        if (!config.crowd.session.lastvalidation) {
            config.crowd.session.lastvalidation= 'session.lastvalidation'
            log.info("Property crowd.session.lastvalidation is not set in Config.groovy. Using default value.")
        }
        if (!config.crowd.session.validationinterval) {
            config.crowd.session.validationinterval= '0'
            log.info("Property crowd.session.validationinterval is not set in Config.groovy. Using default value.")
        }

        // Set up default CrowdAuth properties
        if (!config.crowdAuth.loginController) {
            config.crowdAuth.loginController= 'login'
            log.info("Property crowdAuth.loginController is not set in Config.groovy. Defaulting to supplied login controller.")
        }
        if (!config.crowdAuth.defaultAuthenticate) {
            config.crowdAuth.defaultAuthenticate= false
            log.info("Property crowdAuth.defaultAuthenticate is not set in Config.groovy. Defaulting to false.")
        }
        if (!config.crowdAuth.defaultAuthorize) {
            config.crowdAuth.defaultAuthorize= []
            log.info("Property crowdAuth.defaultAuthorize is not set in Config.groovy. Defaulting to none.")
        }

        // Set up the Crowd client
        propertyUtils(org.codehaus.grails.plugins.crowd.util.PropertyUtils, ConfigurationHolder.config.crowd.toProperties())
        clientProperties(ClientProperties, propertyUtils)
        securityServerClient(SecurityServerClientImpl, clientProperties)
        httpAuthenticator(HttpAuthenticatorImpl, securityServerClient)
    }

    def doWithApplicationContext = { applicationContext ->
        // TODO Implement post initialization spring config (optional)
    }

    def doWithWebDescriptor = { xml ->
        // TODO Implement additions to web.xml (optional)
    }

    def doWithDynamicMethods = { ctx ->
        // TODO Implement registering dynamic methods to classes (optional)
    }

    def onChange = { event ->
        // TODO Implement code that is executed when this class plugin class is changed
        // the event contains: event.application and event.applicationContext objects
    }

    def onApplicationChange = { event ->
        // TODO Implement code that is executed when any class in a GrailsApplication changes
        // the event contain: event.source, event.application and event.applicationContext objects
    }
}
