/* $Id: LoginController.groovy 41035 2008-05-09 05:59:08Z caulfield14 $ */

import com.atlassian.crowd.integration.service.soap.client.SecurityServerClient
import com.atlassian.crowd.integration.http.HttpAuthenticator
import com.atlassian.crowd.integration.exception.InactiveAccountException
import com.atlassian.crowd.integration.exception.InvalidAuthenticationException
import com.atlassian.crowd.integration.exception.InvalidAuthorizationTokenException
import com.atlassian.crowd.integration.soap.SOAPPrincipal
import java.rmi.RemoteException
import org.codehaus.groovy.grails.commons.ConfigurationHolder


/**
 * Controller to process a user login.
 */
class LoginController {
    static authenticate= false
    static authorize= []

    HttpAuthenticator httpAuthenticator
    SecurityServerClient securityServerClient

    /**
     * Action to initiate the login process and render the login view.
     */
    def index = {
        def command = new LoginCommand()
        if (session.authenticate) {
            flash.message = "authorize.user.authenticate"
            session.authenticate = null
        }
        render(view: "login", model: [command:command])
    }

    /**
     * Action to retrieve the login submission and process it.
     */
    def login = {LoginCommand command ->
        // Check for errors and send back if required
        if (command.hasErrors()) {
            command.password= null
            return [command:command]
        }

        // Process login, catch and deal with exceptions
        // If user has been authenticated via Crowd/SSO, the SecurityFilter will set up the session
        // structure at the next request that requires authentication.
        try {
            httpAuthenticator.authenticate(request, response, command.username, command.password)
        }
        catch (InvalidAuthenticationException e) {
            command.errors.reject("crowdAuth.invalidAuthentication")
            command.password= null
            return [command:command]
        }
        catch (InvalidAuthorizationTokenException e) {
            command.errors.reject("crowdAuth.invalidAuthorizationToken")
            command.password= null
            return [command:command]
        }
        catch (RemoteException e) {
            command.errors.reject("crowdAuth.remote")
            command.password= null
            return [command:command]
        }
        catch (InactiveAccountException e) {
            command.errors.reject("crowdAuth.inactiveAccount")
            command.password= null
            return [command:command]
        }

        // If the user was trying to get somewhere else and redirected here, send them on their way.
        // The variable used here would be set by CrowdAuthSecurityFilters before redirecting to login.
        if (session.originalRequestParams) {
            redirect(controller: session.originalRequestParams.controller,
                    action: session.originalRequestParams.action,
                    params: session.originalRequestParams)
            session.originalRequestParams= null
            return;
        }
        else {
            redirect(uri:'/')
        }
    }
}

/**
 * Command object to handle constraints for the login process.
 */
class LoginCommand {
    String username
    String password

    static constraints = {
        username(nullable: false, blank: false)
        password(nullable: false, blank: false)
    }
}