/* $Id: CrowdAuthUtils.groovy 41035 2008-05-09 05:59:08Z caulfield14 $ */

package org.codehaus.grails.plugins.crowd.util

import com.atlassian.crowd.integration.soap.SOAPPrincipal


/**
 * Utility class to retrieve information about the authenticated principal.
 * TODO: the name of the sesison variables should be configurable. See {@link http://jira.codehaus.org/browse/GRAILSPLUGINS-317 GRAILSPLUGINS-317}
 */
static class CrowdAuthUtils {
    /**
     * Retrieves the authenticated principal.
     * @param request a request object which contains a session scope with the principal data
     * @return the SOAPPrincipal object for the authenticated principal
     */
    static SOAPPrincipal getAuthenticatedPrincipal(request) {
        return request.session.principal
    }

    /**
     * Retrieves the groups authenticated principal belongs to.
     * @param request a request object which contains a session scope with the principal data
     * @return the List of the groups' names that the authenticated principal belongs to
     */
    static List<String> getAuthenticatedPrincipalGroups(request) {
        return request.session.principalGroups
    }

    /**
     * Retrieves the roles authenticated principal belongs to.
     * @param request a request object which contains a session scope with the principal data
     * @return the List of the roles' names that the authenticated principal belongs to
     */
    static List<String> getAuthenticatedPrincipalRoles(request) {
        return request.session.principalRoles
    }

    /**
     * Determines if there is currently an authenticated principal.
     * @param request a request object which contains a session scope with the principal data
     * @return true if there is an authenticated principal, false otherwise.
     */
    static Boolean isAuthenticated(request) {
        return request.session.principal? true : false
    }
}